@@ -1,12 +1,13 @@
+from __future__ import annotations
 import dataclasses
-from datetime import date, datetime
-from marshmallow import fields
 import dateutil.parser
-from dataclasses_json import dataclass_json
+from dataclasses_json import Undefined, dataclass_json
+from datetime import datetime
+from marshmallow import fields
 from sdk import utils
 
 
-@dataclass_json
+@dataclass_json(undefined=Undefined.EXCLUDE)
 @dataclasses.dataclass
 class UnboundedRequest:
     r"""UnboundedRequest
@@ -18,4 +19,4 @@ class UnboundedRequest:
     har_size_bytes: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('har_size_bytes') }})
     request_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('request_id') }})
     workspace_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('workspace_id') }})
-    
+    
\ No newline at end of file
