@@ -1,12 +1,24 @@
+from __future__ import annotations
 import dataclasses
-from datetime import date, datetime
-from marshmallow import fields
 import dateutil.parser
-from dataclasses_json import dataclass_json
+from dataclasses_json import Undefined, dataclass_json
+from datetime import datetime
+from marshmallow import fields
 from sdk import utils
 
 
-@dataclass_json
+@dataclass_json(undefined=Undefined.EXCLUDE)
+@dataclasses.dataclass
+class VersionMetadataInput:
+    r"""VersionMetadataInput
+    A set of keys and associated values, attached to a particular version of an Api.
+    """
+    
+    meta_key: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('meta_key') }})
+    meta_value: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('meta_value') }})
+    
+
+@dataclass_json(undefined=Undefined.EXCLUDE)
 @dataclasses.dataclass
 class VersionMetadata:
     r"""VersionMetadata
@@ -19,15 +31,4 @@ class VersionMetadata:
     meta_value: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('meta_value') }})
     version_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('version_id') }})
     workspace_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('workspace_id') }})
-    
-
-@dataclass_json
-@dataclasses.dataclass
-class VersionMetadataInput:
-    r"""VersionMetadataInput
-    A set of keys and associated values, attached to a particular version of an Api.
-    """
-    
-    meta_key: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('meta_key') }})
-    meta_value: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('meta_value') }})
-    
+    
\ No newline at end of file
